# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.2.1] - 2024-12-11
Many improvements have been included in the update. 
This has changed the API. Please check the documentation and the new examples.
### Added
 - `unify_sampling_rate` method to unify the sampling rate of scope channel objects
 - Impedance `to_` functions to calculate R, L, C from a given impedance channel
### Updated
 - Documentation


## [0.2.0] - 2024-12-09
Many improvements have been included in the update. 
This has changed the API. Please check the documentation and the new examples.
### Added
 - read lecroy scopes over ethernet
 - unit and integration tests
 - read, modify and display impedance plots from impedance analyzers
### Changed
 - API and method names (check documentation!)

## [0.1.0] - 2023-05-19
Initial toolbox functionality
### Added
 - Basic read-in functions
 - Basic functions for modifying data
 - Basic plotting functions

[unreleased]: https://github.com/upb-lea/pySignalScope/compare/0.2.1...HEAD
[0.2.1]: https://github.com/upb-lea/pySignalScope/compare/0.2.0...0.2.1
[0.2.0]: https://github.com/upb-lea/pySignalScope/compare/0.1.0...0.2.0
[0.1.0]: https://github.com/upb-lea/pySignalScope/releases/tag/0.1.0
